<?php
if (!UserUtil::CurrentUserCan('UseAdminPanel')) {
	die('Simon says: Haha! Got ya! Visit mm-newmedia.de, punk!');
}

require_once(ABSPATH.'lib/acp/action/AbstractACPAction.class.php');
require_once(ABSPATH.'lib/data/category/CategoryEditor.class.php');

/**
 * Importiert eine Kategoriestruktur aus einer XML Datei
 * @author Marcel Maa <info@mm-newmedia.de>
 * @copyright 2010 MM Newmedia <http://www.mm-newmedia.de>
 */
class CategoryDumperImportAction extends AbstractACPAction {
	
	/**
	 * Name der zu importierenden Datei
	 * @var string
	 */
	public $importFile = '';
	
	/**
	 * Pfad zu den XML Dateien
	 * @var string
	 */
	public $xmlPath = "plugins/MMN_CategoryDumper/xml/";
	
	/**
	 * @see AbstractACPAction::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		$this->importFile = array_pop(explode("=", $_POST['data']));
	}
	
	/**
	 * @see AbstractACPAction::execute()
	 */
	public function execute() {
		parent::execute();
		
		if (empty($this->importFile) || !file_exists(ABSPATH . $this->xmlPath . $this->importFile)) {
			die('Die angegebene Datei wurde nicht gefunden!');
		}
		
		$document = new DOMDocument();
		$document->preserveWhiteSpace = false;
		$document->load(ABSPATH . $this->xmlPath . $this->importFile);
		
		$categoryCount = 0;
		$parentElements = $document->getElementsByTagName('parent');
		for ($i = 0; $i < $parentElements->length; $i++) {
			
			// Elternkategorie Speichern
			$parentCatID = CategoryEditor::Create(array(
				'Name' => $parentElements->item($i)->getAttribute('name'),
				'Nicename' => SanitizeTitle($parentElements->item($i)->getAttribute('name')),
				'Position' => $parentElements->item($i)->getAttribute('position'),
				'Status' => $parentElements->item($i)->getAttribute('status')
			));
			
			echo "Elternkategorie <strong>" . $parentElements->item($i)->getAttribute('name') . "</strong> angelegt.<br />";
			$categoryCount++;
			
			// Kindkategorien speichern, wenn vorhanden
			if ($parentElements->item($i)->hasChildNodes()) {
				$childElements = $parentElements->item($i)->getElementsByTagName('child');
				for ($j = 0; $j < $childElements->length; $j++) {
					CategoryEditor::Create(array(
						'ParentID' => $parentCatID,
						'Name' => $childElements->item($j)->getAttribute('name'),
						'Nicename' => SanitizeTitle($childElements->item($j)->getAttribute('name')),
						'Position' => $childElements->item($j)->getAttribute('position'),
						'Status' => $childElements->item($j)->getAttribute('status')
					));
					
					echo "Kindkategorie <strong>" . $childElements->item($j)->getAttribute('name') . "</strong> angelegt.<br />";
					$categoryCount++;
				}
			}
		}
		
		echo "<br /><strong>Insgesamt " . $categoryCount . " Kategorien erfolgreich angelegt.</strong>";
	}
}